@@ -447,7 +447,7 @@ class PostgresClient(AbstractClient):
 
 
     def DescribeDBSlowlogs(self, request):
-        """本接口（DescribeDBSlowlogs）用于获取慢查询日志。
+        """本接口（DescribeDBSlowlogs）用于获取慢查询日志。已于2021.09.01日正式废弃，后续此接口将不再返回任何数据，新接口为DescribeSlowQueryList，详细请查看：https://cloud.tencent.com/document/product/409/60540
 
         :param request: Request instance for DescribeDBSlowlogs.
         :type request: :class:`tencentcloud.postgres.v20170312.models.DescribeDBSlowlogsRequest`
@@ -671,7 +671,7 @@ class PostgresClient(AbstractClient):
 
 
     def DescribeSlowQueryAnalysis(self, request):
-        """慢查询统计分析接口，根据SQL语句抽象参数之后，进行聚合分析，并返回对应结果
+        """此接口（DescribeSlowQueryAnalysis）用于统计指定时间范围内的所有慢查询，根据SQL语句抽象参数后，进行聚合分析，并返回同类SQL列表。
 
         :param request: Request instance for DescribeSlowQueryAnalysis.
         :type request: :class:`tencentcloud.postgres.v20170312.models.DescribeSlowQueryAnalysisRequest`
@@ -699,7 +699,7 @@ class PostgresClient(AbstractClient):
 
 
     def DescribeSlowQueryList(self, request):
-        """获取慢查询列表
+        """此接口（DescribeSlowQueryList）用于查询指定时间范围内的所有慢查询。
 
         :param request: Request instance for DescribeSlowQueryList.
         :type request: :class:`tencentcloud.postgres.v20170312.models.DescribeSlowQueryListRequest`
